@@ -88,14 +88,16 @@ rabbit_opts = [
                help='SSL certification authority file '
                     '(valid only if SSL enabled).'),
     cfg.BoolOpt('heartbeat_in_pthread',
-                default=False,
-                help="EXPERIMENTAL: Run the health check heartbeat thread "
-                     "through a native python thread. By default if this "
-                     "option isn't provided the  health check heartbeat will "
-                     "inherit the execution model from the parent process. By "
-                     "example if the parent process have monkey patched the "
+                default=True,
+                help="Run the health check heartbeat thread "
+                     "through a native python thread by default. If this "
+                     "option is equal to False then the health check "
+                     "heartbeat will inherit the execution model "
+                     "from the parent process. For "
+                     "example if the parent process has monkey patched the "
                      "stdlib by using eventlet/greenlet then the heartbeat "
-                     "will be run through a green thread."),
+                     "will be run through a green thread.",
+                deprecated_for_removal=True),
     cfg.FloatOpt('kombu_reconnect_delay',
                  default=1.0,
                  deprecated_group='DEFAULT',
@@ -167,12 +169,18 @@ rabbit_opts = [
                default=2,
                help='How often times during the heartbeat_timeout_threshold '
                'we check the heartbeat.'),
-    cfg.IntOpt('direct_mandatory_flag',
-               default=True,
-               help='Enable/Disable the RabbitMQ mandatory flag '
-               'for direct send. The direct send is used as reply, '
-               'so the MessageUndeliverable exception is raised '
-               'in case the client queue does not exist.'),
+    cfg.BoolOpt('direct_mandatory_flag',
+                default=True,
+                deprecated_for_removal=True,
+                deprecated_reason='Mandatory flag no longer deactivable.',
+                help='(DEPRECATED) Enable/Disable the RabbitMQ mandatory '
+                'flag for direct send. The direct send is used as reply, '
+                'so the MessageUndeliverable exception is raised '
+                'in case the client queue does not exist.'
+                'MessageUndeliverable exception will be used to loop for a '
+                'timeout to lets a chance to sender to recover.'
+                'This flag is deprecated and it will not be possible to '
+                'deactivate this functionality anymore'),
     cfg.BoolOpt('enable_cancel_on_failover',
                 default=False,
                 help="Enable x-cancel-on-ha-failover flag so that "
@@ -510,6 +518,7 @@ class Connection(object):
             # if it was already monkey patched by eventlet/greenlet.
             global threading
             threading = stdlib_threading
+
         self.direct_mandatory_flag = driver_conf.direct_mandatory_flag
 
         if self.ssl:
@@ -1259,11 +1268,11 @@ class Connection(object):
 
         _set_current_channel is responsible to cleanup the cache.
         """
-        queue_indentifier = (exchange.name, routing_key)
+        queue_identifier = (exchange.name, routing_key)
         # NOTE(sileht): We only do it once per reconnection
         # the Connection._set_current_channel() is responsible to clear
         # this cache
-        if queue_indentifier not in self._declared_queues:
+        if queue_identifier not in self._declared_queues:
             queue = kombu.entity.Queue(
                 channel=self.channel,
                 exchange=exchange,
@@ -1277,7 +1286,7 @@ class Connection(object):
                 'Connection._publish_and_creates_default_queue: '
                 'declare queue %(key)s on %(exchange)s exchange', log_info)
             queue.declare()
-            self._declared_queues.add(queue_indentifier)
+            self._declared_queues.add(queue_identifier)
 
         self._publish(exchange, msg, routing_key=routing_key, timeout=timeout)
 
@@ -1387,6 +1396,10 @@ class RabbitDriver(amqpdriver.AMQPDriverBase):
         # the pool configuration properties
         max_size = conf.oslo_messaging_rabbit.rpc_conn_pool_size
         min_size = conf.oslo_messaging_rabbit.conn_pool_min_size
+        if max_size < min_size:
+            raise RuntimeError(
+                f"rpc_conn_pool_size: {max_size} must be greater than "
+                f"or equal to conn_pool_min_size: {min_size}")
         ttl = conf.oslo_messaging_rabbit.conn_pool_ttl
 
         connection_pool = pool.ConnectionPool(
