@@ -1,3 +1,4 @@
+#!/usr/bin/env python3
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
 #    not use this file except in compliance with the License. You may obtain
 #    a copy of the License at
@@ -10,8 +11,12 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import eventlet  # noqa
-eventlet.monkey_patch()  # noqa
+try:
+    # Avoid https://github.com/PyCQA/pycodestyle/issues/472
+    import eventlet
+    eventlet.monkey_patch()
+except ImportError:
+    raise
 
 import argparse
 import bisect
@@ -23,7 +28,6 @@ import logging
 import os
 import random
 import signal
-import six
 import socket
 import string
 import sys
@@ -139,7 +143,7 @@ class MessageStatsCollector(object):
         max_latency = 0
         sum_latencies = 0
 
-        for i in six.moves.range(count):
+        for i in range(count):
             p = self.buffer[i]
             size += len(p.cargo)
 
@@ -471,10 +475,10 @@ def generate_messages(messages_count):
         messages_count = MESSAGES_LIMIT
     LOG.info("Generating %d random messages", messages_count)
     generator = init_random_generator()
-    for i in six.moves.range(messages_count):
+    for i in range(messages_count):
         length = generator()
         msg = ''.join(random.choice(
-                      string.ascii_lowercase) for x in six.moves.range(length))
+                      string.ascii_lowercase) for x in range(length))
         MESSAGES.append(msg)
 
     LOG.info("Messages has been prepared")
@@ -533,7 +537,7 @@ def spawn_rpc_clients(threads, transport, targets, wait_after_msg, timeout,
     p = eventlet.GreenPool(size=threads)
     targets = itertools.cycle(targets)
 
-    for i in six.moves.range(threads):
+    for i in range(threads):
         target = next(targets)
         LOG.debug("starting RPC client for target %s", target)
         client_builder = functools.partial(RPCClient, i, transport, target,
@@ -548,7 +552,7 @@ def spawn_rpc_clients(threads, transport, targets, wait_after_msg, timeout,
 def spawn_notify_clients(threads, topic, transport, message_count,
                          wait_after_msg, timeout, duration):
     p = eventlet.GreenPool(size=threads)
-    for i in six.moves.range(threads):
+    for i in range(threads):
         client_builder = functools.partial(NotifyClient, i, transport, [topic],
                                            wait_after_msg)
         p.spawn_n(send_messages, i, client_builder, message_count, duration)
@@ -574,7 +578,7 @@ def send_messages(client_id, client_builder, messages_count, duration):
     else:
         LOG.debug("Sending %d messages using client %d",
                   messages_count, client_id)
-        for _ in six.moves.range(messages_count):
+        for _ in range(messages_count):
             client.send_msg()
             eventlet.sleep()
             if not IS_RUNNING:
